@@ -2,12 +2,9 @@
 /// Dialog boxes to prompt the user for things.
 pub mod dialogs;
 pub mod parse;
-#[cfg(feature = "config")]
-mod keybinds;
-#[cfg(feature = "config")]
-pub use keybinds::KeybindsRaw;
 mod run;
-#[cfg(feature = "timing")]
+#[cfg(feature = "config")]
+pub mod config;
 /// Functions to format times.
 pub mod timing;
 pub use run::Run;
